@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 /// Run a command and return the data it wrote to stdout as a string
 pub(crate) fn output(mut command: Command) -> Result<String, OutputError> {
