@@ -24,7 +24,6 @@ pub(crate) use {
   tempfile::TempDir,
   temptree::{temptree, tree, Tree},
   which::which,
-  yaml_rust::YamlLoader,
 };
 
 #[macro_use]
@@ -48,7 +47,7 @@ mod error_messages;
 mod evaluate;
 mod examples;
 mod export;
-mod fall_back_to_parent;
+mod fallback;
 mod fmt;
 mod functions;
 mod ignore_comments;
@@ -78,10 +77,17 @@ mod shell;
 mod show;
 mod slash_operator;
 mod string;
-mod sublime_syntax;
 mod subsequents;
 mod tempdir;
 mod undefined_variables;
 #[cfg(target_family = "windows")]
 mod windows_shell;
 mod working_directory;
+
+fn path(s: &str) -> String {
+  if cfg!(windows) {
+    s.replace('/', "\\")
+  } else {
+    s.into()
+  }
+}
